@@ -23,8 +23,8 @@ along with this program.  If not, see <http://www.gnu.org/licenses/>.
 
 
 __author__ = 'Alexandre Norman (norman at xael.org)'
-__version__ = '0.3.13'
-__last_modification__ = '2015.03.21'
+__version__ = '0.4.0'
+__last_modification__ = '2015.06.06'
 
 import copy
 import datetime
@@ -220,7 +220,7 @@ def make_task_from_node(n, prop={}, prev_task=''):
         ress = "{0}".format(["{0}".format(x) for x in n.properties['allocate'].replace(",", " ").split()]).replace("'", "")
     else:
         try:
-            ress = "{0}".format(["{0}".format(x.strip()) for x in prop['resources'].replace('[','').replace(']','').split(',') if x not in LISTE_IGNORE_TAGS]).replace("'", "")
+            ress = "{0}".format(["{0}".format(x.strip()) for x in prop['resources'].replace('[','').replace(']','').split(',') if x.strip() not in LISTE_IGNORE_TAGS]).replace("'", "")
         except KeyError:
             ress = None
         except TypeError:
@@ -244,7 +244,7 @@ def make_task_from_node(n, prop={}, prev_task=''):
         __LOG__.critical('** Task "{0}" : no start, stop, duration or dependencies -> not included in gantt !'.format(fullname))
         return None
     
-    gantt_code += "task_{0} = gantt.Task(name='{1}', start={2}, stop={6}, duration={3}, resources={4}, depends_of={5}, percent_done={7}, fullname='{8}', color={9}, display={10})\n".format(name, name, start, duration, ress, None, end, percentdone, fullname, color, display)
+    gantt_code += "task_{0} = gantt.Task(name='{1}', start={2}, stop={6}, duration={3}, resources={4}, depends_of={5}, percent_done={7}, fullname='{8}', color={9}, display={10}, state='{11}')\n".format(name, name, start, duration, ress, None, end, percentdone, fullname, color, display, n.todo)
 
     # store dependencies for later
     dependencies = str(depends_of).replace("'", "")
@@ -257,15 +257,18 @@ def make_task_from_node(n, prop={}, prev_task=''):
 @clize.clize(
     alias = {
         'debug': ('d',),
+        'csv': ('c',),
         'warning': ('w',),
         'gantt': ('g',),
         'svg': ('S',),
         'resource': ('r',),
         'availibility': ('a',),
+        'one_line_for_tasks': ('o',),
         'start_date': ('s',),
         'end_date': ('e',),
         'today': ('t',),
         'filter': ('f',),
+        'scale': ('k',),
         },
     extra = (
         clize.make_flag(
@@ -275,7 +278,7 @@ def make_task_from_node(n, prop={}, prev_task=''):
             ),
         )
     )
-def __main__(org, gantt='', start_date='', end_date='', today='', debug=False, resource=False, svg='project', filter='', availibility='', warning=False):
+def __main__(org, csv='', gantt='', start_date='', end_date='', today='', debug=False, resource=False, svg='project', filter='', availibility='', warning=False, one_line_for_tasks=False, scale='d'):
     """
     org2gantt.py
     
@@ -285,10 +288,12 @@ def __main__(org, gantt='', start_date='', end_date='', today='', debug=False, r
 
     svg: svg base name for files output
 
-    resource: generate resources graphe
+    resource: generate resources graph
 
     availibility: check resource availibility between start_date and end_date
 
+    one_line_for_tasks: generate graph for each resources with all tasks on the same line
+
     start_date: force start date for output or used for checking resource availibility (format : 'yyyy-mm-dd' or '-1w' (from today))
 
     end_date: force end date for output or used for checking resource availibility (format : 'yyyy-mm-dd' or '+2d' (from today))
@@ -296,6 +301,10 @@ def __main__(org, gantt='', start_date='', end_date='', today='', debug=False, r
     today: force today date (format : 'yyyy-mm-dd')
 
     filter: tag or list of tags separated by comas to filter
+
+    scale: scale for the graph (d: days, w: weeks, m: months, q: quaterly)
+
+    csv: filename for csv output
     
     debug: debug
 
@@ -354,7 +363,12 @@ import gantt
     planning_today_date = _iso_date_to_datetime(str(datetime.date.today()))
     my_today = datetime.date.today()
     bar_color = {'TODO':'#FFFF90'}
-    one_line_for_tasks = False
+
+    if one_line_for_tasks and not resource:
+        __LOG__.critical('option one_line_for_tasks must be used in conjonction with resource graph generation')
+        sys.exit(-1)
+        
+
     global LISTE_IGNORE_TAGS
     LISTE_IGNORE_TAGS = []
 
@@ -374,7 +388,7 @@ import gantt
         if 'ignore_tags' in n_configuration.properties:
              LISTE_IGNORE_TAGS = n_configuration.properties['ignore_tags'].split()
 
-        if 'one_line_for_tasks' in n_configuration.properties and n_configuration.properties['one_line_for_tasks'].strip() == 't':
+        if not one_line_for_tasks and ('one_line_for_tasks' in n_configuration.properties and n_configuration.properties['one_line_for_tasks'].strip() == 't'):
              one_line_for_tasks = True
 
         if today != '':
@@ -470,11 +484,31 @@ import gantt
                     sys.exit(-1)
 
 
+
     if planning_end_date <= planning_start_date:
         __LOG__.critical('planning_end_date [{0}] is before planning_start_date [{1}]...'.format(planning_end_date, planning_start_date))
         sys.exit(-1)
 
 
+    if scale != '':
+        scale_ref = {
+            'd': 'DRAW_WITH_DAILY_SCALE',
+            'w': 'DRAW_WITH_WEEKLY_SCALE',
+            'm': 'DRAW_WITH_MONTHLY_SCALE',
+            'q': 'DRAW_WITH_QUATERLY_SCALE',
+            }
+        try:
+            scale_name = scale_ref[scale]
+        except KeyError:
+            __LOG__.critical('unknown scale {0}'.format(scale))
+            sys.exit(-1)
+        else:
+            __LOG__.info('drawing with scale : {0}'.format(scale_name))
+    else:
+        scale_name = 'DRAW_WITH_DAILY_SCALE'
+            
+
+
     __LOG__.debug('List of ignored tags : {0}'.format(LISTE_IGNORE_TAGS))
 
 
@@ -817,17 +851,22 @@ import gantt
         gantt_code += "\n#### Outputs \n"
 
 
-        gantt_code += "project.make_svg_for_tasks(filename='{3}.svg', today={0}, start={1}, end={2})\n".format(planning_today_date, planning_start_date, planning_end_date, svg)
+        gantt_code += "project.make_svg_for_tasks(filename='{3}.svg', today={0}, start={1}, end={2}, scale=gantt.{4})\n".format(planning_today_date, planning_start_date, planning_end_date, svg, scale_name)
         # Generate resource graph
         if resource:
-            gantt_code += "project.make_svg_for_resources(filename='{4}_resources.svg', today={0}, start={1}, end={2}, one_line_for_tasks={3}, filter='{5}')\n".format(planning_today_date, planning_start_date, planning_end_date, one_line_for_tasks, svg, filter)
-
+            gantt_code += "project.make_svg_for_resources(filename='{4}_resources.svg', today={0}, start={1}, end={2}, one_line_for_tasks={3}, filter='{5}', scale=gantt.{6})\n".format(planning_today_date, planning_start_date, planning_end_date, one_line_for_tasks, svg, filter, scale_name)
+            
     else:
         gantt_code += "\n#### Check resource availibility \n"
         gantt_code += "print({0}.is_vacant(from_date={1}, to_date={2}))\n".format(availibility, planning_start_date, planning_end_date)
         
 
 
+    if csv != '':
+        gantt_code += "\n#### CSV Outputs \n"
+        gantt_code += "project.csv('{0}')\n".format(csv)
+
+
     # write Gantt code
     if gantt == '':
         import gantt
